@@ -155,7 +155,7 @@ class ARQ:
 
         return results
 
-    async def wall(self, query: str, limit: int):
+    async def wall(self, query: str):
         """
         Returns An Object.
 
